@@ -29,6 +29,29 @@ from bs4.builder import (
 )
 default_builder = HTMLParserTreeBuilder
 
+# Some tests depend on specific third-party libraries. We use
+# @pytest.mark.skipIf on the following conditionals to skip them
+# if the libraries are not installed.
+try:
+    from soupsieve import SelectorSyntaxError
+    SOUP_SIEVE_PRESENT = True
+except ImportError:
+    SOUP_SIEVE_PRESENT = False
+
+try:
+    import html5lib
+    HTML5LIB_PRESENT = True
+except ImportError:
+    HTML5LIB_PRESENT = False
+
+try:
+    import lxml.etree
+    LXML_PRESENT = True
+    LXML_VERSION = lxml.etree.LXML_VERSION
+except ImportError:
+    LXML_PRESENT = False
+    LXML_VERSION = (0,)
+
 BAD_DOCUMENT = """A bare string
 <!DOCTYPE xsl:stylesheet SYSTEM "htmlent.dtd">
 <!DOCTYPE xsl:stylesheet PUBLIC "htmlent.dtd">
@@ -258,10 +281,10 @@ class TreeBuilderSmokeTest(object):
 
     @pytest.mark.parametrize(
         "multi_valued_attributes",
-        [None, dict(b=['class']), {'*': ['notclass']}]
+        [None, {}, dict(b=['class']), {'*': ['notclass']}]
     )
     def test_attribute_not_multi_valued(self, multi_valued_attributes):
-        markup = '<a class="a b c">'
+        markup = '<html xmlns="http://www.w3.org/1999/xhtml"><a class="a b c"></html>'
         soup = self.soup(markup, multi_valued_attributes=multi_valued_attributes)
         assert soup.a['class'] == 'a b c'
 
@@ -820,26 +843,27 @@ Hello, world!
         soup = self.soup(text)
         assert soup.p.encode("utf-8") == expected
 
-    def test_real_iso_latin_document(self):
+    def test_real_iso_8859_document(self):
         # Smoke test of interrelated functionality, using an
         # easy-to-understand document.
 
-        # Here it is in Unicode. Note that it claims to be in ISO-Latin-1.
-        unicode_html = '<html><head><meta content="text/html; charset=ISO-Latin-1" http-equiv="Content-type"/></head><body><p>Sacr\N{LATIN SMALL LETTER E WITH ACUTE} bleu!</p></body></html>'
+        # Here it is in Unicode. Note that it claims to be in ISO-8859-1.
+        unicode_html = '<html><head><meta content="text/html; charset=ISO-8859-1" http-equiv="Content-type"/></head><body><p>Sacr\N{LATIN SMALL LETTER E WITH ACUTE} bleu!</p></body></html>'
 
-        # That's because we're going to encode it into ISO-Latin-1, and use
-        # that to test.
+        # That's because we're going to encode it into ISO-8859-1,
+        # and use that to test.
         iso_latin_html = unicode_html.encode("iso-8859-1")
 
-        # Parse the ISO-Latin-1 HTML.
+        # Parse the ISO-8859-1 HTML.
         soup = self.soup(iso_latin_html)
+
         # Encode it to UTF-8.
         result = soup.encode("utf-8")
 
         # What do we expect the result to look like? Well, it would
         # look like unicode_html, except that the META tag would say
-        # UTF-8 instead of ISO-Latin-1.
-        expected = unicode_html.replace("ISO-Latin-1", "utf-8")
+        # UTF-8 instead of ISO-8859-1.
+        expected = unicode_html.replace("ISO-8859-1", "utf-8")
 
         # And, of course, it would be in UTF-8, not Unicode.
         expected = expected.encode("utf-8")
@@ -1177,15 +1201,3 @@ class HTML5TreeBuilderSmokeTest(HTMLTreeBuilderSmokeTest):
         assert isinstance(soup.contents[0], Comment)
         assert soup.contents[0] == '?xml version="1.0" encoding="utf-8"?'
         assert "html" == soup.contents[0].next_element.name
-
-def skipIf(condition, reason):
-   def nothing(test, *args, **kwargs):
-       return None
-
-   def decorator(test_item):
-       if condition:
-           return nothing
-       else:
-           return test_item
-
-   return decorator
